[Libreoffice-commits] core.git: sc/source

Libreoffice Gerrit user logerrit at kemper.freedesktop.org
Tue Nov 6 18:33:59 UTC 2018


 sc/source/filter/excel/excform.cxx |   22 +++++++++++-----------
 1 file changed, 11 insertions(+), 11 deletions(-)

New commits:
commit bc42b6bfa49cc2b58201a8f6177dd3b1a0c038d8
Author:     Johnny_M <klasse at partyheld.de>
AuthorDate: Sun Nov 4 12:31:40 2018 +0100
Commit:     Bartosz Kosiorek <gang65 at poczta.onet.pl>
CommitDate: Tue Nov 6 19:32:26 2018 +0100

    tdf#39674 Translate German variable names
    
    Change-Id: Id4eee662715246bf58653287fed5ecb954e88dfc
    Reviewed-on: https://gerrit.libreoffice.org/62836
    Tested-by: Jenkins
    Reviewed-by: Bartosz Kosiorek <gang65 at poczta.onet.pl>

diff --git a/sc/source/filter/excel/excform.cxx b/sc/source/filter/excel/excform.cxx
index ed4078f5fe25..7989d2610012 100644
--- a/sc/source/filter/excel/excform.cxx
+++ b/sc/source/filter/excel/excform.cxx
@@ -1537,7 +1537,7 @@ void ExcelToSc::GetAbsRefs( ScRangeList& rRangeList, XclImpStream& rStrm, std::s
 void ExcelToSc::DoMulArgs( DefTokenId eId, sal_uInt8 nCnt )
 {
     TokenId                 eParam[ 256 ];
-    sal_Int32                   nLauf;
+    sal_Int32               nPass;
 
     if( eId == ocCeil || eId == ocFloor )
     {
@@ -1545,11 +1545,11 @@ void ExcelToSc::DoMulArgs( DefTokenId eId, sal_uInt8 nCnt )
         nCnt++;
     }
 
-    for( nLauf = 0; aStack.HasMoreTokens() && (nLauf < nCnt); nLauf++ )
-        aStack >> eParam[ nLauf ];
+    for( nPass = 0; aStack.HasMoreTokens() && (nPass < nCnt); nPass++ )
+        aStack >> eParam[ nPass ];
     // #i70925# reduce parameter count, if no more tokens available on token stack
-    if( nLauf < nCnt )
-        nCnt = static_cast< sal_uInt8 >( nLauf );
+    if( nPass < nCnt )
+        nCnt = static_cast< sal_uInt8 >( nPass );
 
     if( nCnt > 0 && eId == ocExternal )
     {
@@ -1586,13 +1586,13 @@ void ExcelToSc::DoMulArgs( DefTokenId eId, sal_uInt8 nCnt )
         else if( eId == ocIf )
         {
             sal_uInt16          nNullParam = 0;
-            for( nLauf = 0 ; nLauf < nCnt ; nLauf++ )
+            for( nPass = 0 ; nPass < nCnt ; nPass++ )
             {
-                if( aPool.IsSingleOp( eParam[ nLauf ], ocMissing ) )
+                if( aPool.IsSingleOp( eParam[ nPass ], ocMissing ) )
                 {
                     if( !nNullParam )
                         nNullParam = static_cast<sal_uInt16>(aPool.Store( 0.0 ));
-                    eParam[ nLauf ] = nNullParam;
+                    eParam[ nPass ] = nNullParam;
                 }
             }
         }
@@ -1602,10 +1602,10 @@ void ExcelToSc::DoMulArgs( DefTokenId eId, sal_uInt8 nCnt )
         {
             // nSkipEnd is either 0 or -1 => nLast >= 0
             aPool << eParam[ nLast ];
-            for( nLauf = nLast - 1 ; nLauf > nSkipEnd ; nLauf-- )
+            for( nPass = nLast - 1 ; nPass > nSkipEnd ; nPass-- )
             {
-                // nLauf > nSkipEnd => nLauf >= 0
-                aPool << ocSep << eParam[nLauf];
+                // nPass > nSkipEnd => nPass >= 0
+                aPool << ocSep << eParam[nPass];
             }
         }
     }


More information about the Libreoffice-commits mailing list